<?php
/**
 * Funciones y definiciones de Bigseo Theme
 *
 * @link https://developer.wordpress.org/themes/basics/theme-functions/
 *
 * @package Bigseo_Theme
 */

if ( ! function_exists( 'bigseotheme_setup' ) ) {

	function bigseotheme_setup() {

		load_theme_textdomain( 'bigseotheme', get_template_directory() . '/languages' );

		add_theme_support( 'automatic-feed-links' );

		add_theme_support( 'title-tag' );

		add_theme_support( 'post-thumbnails' );

		register_nav_menus( array('primary' => esc_html__( 'Primary', 'bigseotheme' )) );

		add_theme_support( 'html5', array(
			'search-form',
			'comment-form',
			'comment-list',
			'gallery',
			'caption',
			) );

		add_theme_support( 'custom-logo', array(
			'height'      => 50,
			'width'       => 250,
			'flex-height' => true,
			'flex-width' => true,
			) );

		$defaults = array(
			'default-image'          => '',
			'width'                  => 1920,
			'height'                 => 400,
			'flex-height'            => true,
			'flex-width'             => true,
			'uploads'                => true,
			'random-default'         => false,
			'header-text'            => true,
			);
		add_theme_support( 'custom-header', $defaults );
		add_theme_support( 'custom-background' );


		add_image_size( 'thumbnail-center', 390, 200, array( 'center', 'center' ) );

	}
}
add_action( 'after_setup_theme', 'bigseotheme_setup' );

function bigseotheme_content_width() {
	$GLOBALS['content_width'] = apply_filters( 'bigseotheme_content_width', 640 );
}
add_action( 'after_setup_theme', 'bigseotheme_content_width', 0 );

function bigseotheme_widgets_init() {
	register_sidebar( array(
		'name'          => esc_html__( 'Footer Widget Area 1', 'bigseotheme' ),
		'id'            => 'widget-footer-1',
		'description'   => esc_html__( 'Add widgets here.', 'bigseotheme' ),
		'before_widget' => '<section id="%1$s" class="widget %2$s">',
		'after_widget'  => '</section>',
		'before_title'  => '<h4 class="widget-title">',
		'after_title'   => '</h4>',
		) );

	register_sidebar( array(
		'name'          => esc_html__( 'Footer Widget Area 2', 'bigseotheme' ),
		'id'            => 'widget-footer-2',
		'description'   => esc_html__( 'Add widgets here.', 'bigseotheme' ),
		'before_widget' => '<section id="%1$s" class="widget %2$s">',
		'after_widget'  => '</section>',
		'before_title'  => '<h4 class="widget-title">',
		'after_title'   => '</h4>',
		) );

	register_sidebar( array(
		'name'          => esc_html__( 'Footer Widget Area 3', 'bigseotheme' ),
		'id'            => 'widget-footer-3',
		'description'   => esc_html__( 'Add widgets here.', 'bigseotheme' ),
		'before_widget' => '<section id="%1$s" class="widget %2$s">',
		'after_widget'  => '</section>',
		'before_title'  => '<h4 class="widget-title">',
		'after_title'   => '</h4>',
		) );

	register_sidebar( array(
		'name'          => esc_html__( 'Footer Widget Area 4', 'bigseotheme' ),
		'id'            => 'widget-footer-4',
		'description'   => esc_html__( 'Add widgets here.', 'bigseotheme' ),
		'before_widget' => '<section id="%1$s" class="widget %2$s">',
		'after_widget'  => '</section>',
		'before_title'  => '<h4 class="widget-title">',
		'after_title'   => '</h4>',
		) );

	register_sidebar( array(
		'name'          => esc_html__( 'Shop Sidebar', 'bigseotheme' ),
		'id'            => 'shop',
		'description'   => esc_html__( 'Add widgets here.', 'bigseotheme' ),
		'before_widget' => '<section id="%1$s" class="widget %2$s">',
		'after_widget'  => '</section>',
		'before_title'  => '<h4 class="widget-title">',
		'after_title'   => '</h4>',
		) );
}
add_action( 'widgets_init', 'bigseotheme_widgets_init' );

if ( ! function_exists( 'bigseotheme_fonts_url' ) ) {
	function bigseotheme_fonts_url() {
		$fonts_url = '';
		$fonts     = array();
		$subsets   = 'latin,latin-ext';

		if ( 'off' !== _x( 'on', 'Roboto font: on or off', 'bigseotheme' ) ) {
			$fonts[] = 'Roboto:100,300,400,700';
		}

		if ( $fonts ) {
			$fonts_url = add_query_arg( array(
				'family' => urlencode( implode( '|', $fonts ) ),
				'subset' => urlencode( $subsets ),
				), 'https://fonts.googleapis.com/css' );
		}

		return $fonts_url;
	}
}

function bigseotheme_scripts() {

	wp_enqueue_style( 'bigseotheme-fonts', bigseotheme_fonts_url(), array(), null );

	wp_enqueue_style( 'bigseotheme-style', get_template_directory_uri() . '/assets/css/main.css' );

	wp_enqueue_script( 'bigseotheme-touchSwipe', get_template_directory_uri() . '/assets/js/swipe.js', array('jquery'), '20151215', true );

	wp_enqueue_script( 'bigseotheme-main', get_template_directory_uri() . '/assets/js/main.js', array('jquery'), '20151215', true );

	if ( is_singular() && comments_open() && get_option( 'thread_comments' ) ) {
		wp_enqueue_script( 'comment-reply' );
	}
}
add_action( 'wp_enqueue_scripts', 'bigseotheme_scripts' );


require get_template_directory() . '/inc/template-tags.php';
require get_template_directory() . '/inc/extras.php';
require get_template_directory() . '/inc/meta-box.php';
require get_template_directory() . '/inc/actions.php';
require get_template_directory() . '/inc/jetpack.php';
require get_template_directory() . '/inc/yoast-filters.php';
require get_template_directory() . '/inc/ads.php';


function wpdocs_theme_add_editor_styles() {
    add_editor_style( 'assets/css/editor-style.css' );
}
add_action( 'admin_init', 'wpdocs_theme_add_editor_styles' );