<?php

//Head cleaner
remove_action( 'wp_head', 'rest_output_link_wp_head', 10 );
remove_action( 'wp_head', 'wp_oembed_add_discovery_links', 10 );
remove_action('wp_head', 'print_emoji_detection_script', 7);
remove_action('wp_print_styles', 'print_emoji_styles');
remove_action('wp_head', 'wp_generator');
add_filter('comment_text', 'wp_filter_nohtml_kses');
add_filter('comment_text_rss', 'wp_filter_nohtml_kses');
add_filter('comment_excerpt', 'wp_filter_nohtml_kses');


//Extra Options
add_filter('comment_reply_link', 'bigseotheme_reply_link_class');
add_filter( 'mce_buttons', 'bigseotheme_next_page', 1, 2 );
add_filter('upload_mimes', 'bigseotheme_svg_mimes');
add_filter( 'body_class', 'bigseotheme_check_sidebar_class' );
add_filter( 'get_custom_logo', 'bigseo_customize_logo_html' );
add_action('wp_head','bigseotheme_the_custom_jumbotron' );
add_action( 'init', 'bigseotheme_excerpts_to_pages' );
add_action( 'edit_category', 'bigseotheme_category_transient_flusher' );
add_action( 'save_post',     'bigseotheme_category_transient_flusher' );




function bigseotheme_reply_link_class($class){
	$class = str_replace("class='comment-reply-link", "class='btn btn-flat btn-colored", $class);
	return $class;
}


function bigseotheme_next_page( $buttons, $id ){
	if ( 'content' != $id )
		return $buttons;
	array_splice( $buttons, 13, 0, 'wp_page' );
	return $buttons;
}


function bigseotheme_page_layout($default = ""){

	if(bigseotheme_get_option_page('layout')){
		return bigseotheme_get_option_page('layout');
	}else{
		return $default;
	}
	
}



function bigseotheme_svg_mimes($mimes) {
	$mimes['svg'] = 'image/svg+xml';
	//$mimes['woff2'] = 'font/woff2';
	return $mimes;
}


function bigseotheme_check_sidebar_class( $classes ) {


	if ( ! is_active_sidebar( 'pages' ) && is_page() 
		|| ! is_active_sidebar( 'posts' ) && is_single() 
		|| ! is_active_sidebar( 'archives' ) && is_archive()
		|| ! is_active_sidebar( 'page-home' ) && is_home()) 
	{
		$classes[] = 'no-sidebar';
	}

	return $classes;
}


function bigseo_customize_logo_html() {
	$bigseo_custom_logo = get_theme_mod( 'custom_logo' );
	$html = sprintf( '<a href="%1$s" class="custom-logo-link">%2$s</a>',
		esc_url( home_url( '/' ) ),
		wp_get_attachment_image( $bigseo_custom_logo, 'full', false, array(
			'class'    => 'custom-logo',
			) )
		);
	return $html;   
}

if ( ! function_exists( 'bigseotheme_the_custom_logo' ) ) {
	function bigseotheme_the_custom_logo() {
		if ( function_exists( 'the_custom_logo' ) ) {
			the_custom_logo();
		}
	}
}

if ( ! function_exists( 'bigseotheme_the_custom_jumbotron' ) ) {

	function bigseotheme_the_custom_jumbotron() {
		if ( is_page() || is_single() ) {
			if (has_post_thumbnail()) {
				echo '<style>
				.jumbotron, .group-image {
					background-image: url(' . get_the_post_thumbnail_url(get_the_ID(), 'full') .');
				}
			</style>';
		}
	}elseif(is_home()) {
		echo '<style>
		.jumbotron {
			background-image: url(' . get_the_post_thumbnail_url(get_option( 'page_for_posts' ), 'full') .');
		}</style>'; }
	}
}


function bigseotheme_excerpts_to_pages() {
	add_post_type_support( 'page', 'excerpt' );
}

function bigseotheme_categorized_blog() {
	if ( false === ( $all_the_cool_cats = get_transient( 'bigseotheme_categories' ) ) ) {

		$all_the_cool_cats = get_categories( array(
			'fields'     => 'ids',
			'hide_empty' => 1,
			'number'     => 2,
			) );

		$all_the_cool_cats = count( $all_the_cool_cats );

		set_transient( 'bigseotheme_categories', $all_the_cool_cats );
	}

	if ( $all_the_cool_cats > 1 ) {
		return true;
	} else {
		return false;
	}
}

function bigseotheme_category_transient_flusher() {
	if ( defined( 'DOING_AUTOSAVE' ) && DOING_AUTOSAVE ) {
		return;
	}
	delete_transient( 'bigseotheme_categories' );
}

add_filter( 'post_gallery', function( $html, $attr, $instance )
{
	if( isset( $attr['class'] ) && $class = $attr['class'] )
	{

		unset( $attr['class'] ); 

		$html = sprintf( 
			'<div class="gallery-%s">%s</div>',
			esc_attr( $class ),
			gallery_shortcode( $attr )
			);
	}

	return $html;

}, 10 ,3 );



function bigseotheme_defer_parsing_of_js ( $url ) {

	if (!(is_admin() )) {
		if ( FALSE === strpos( $url, '.js' ) ) return $url;


		//return "$url' defer='";
	}

	return $url;
}
add_filter( 'clean_url', 'bigseotheme_defer_parsing_of_js', 11, 1 );