<?php
/**
* Custom template tags for this theme.
*
* Eventually, some of the functionality here could be replaced by core features.
*
* @package Bigseo_Theme
*/



if ( ! function_exists( 'bigseotheme_entry_footer' ) ) {

	function bigseotheme_entry_footer() {

		if ( 'post' === get_post_type() ) {

			$categories_list = get_the_category_list( esc_html__( ', ', 'bigseotheme' ) );
			if ( $categories_list && bigseotheme_categorized_blog() ) {
				printf( '<span class="cat-links">' . esc_html__( 'Posted in %1$s', 'bigseotheme' ) . '</span>', $categories_list );
			}

			$tags_list = get_the_tag_list( '', esc_html__( ', ', 'bigseotheme' ) );
			if ( $tags_list ) {
				printf( '<span class="tags-links">' . esc_html__( 'Tagged %1$s', 'bigseotheme' ) . '</span>', $tags_list );
			}
		}

		if ( ! is_single() && ! post_password_required() && ( comments_open() || get_comments_number() ) ) {
			echo '<span class="comments-link">';

			comments_popup_link( sprintf( wp_kses( __( 'Leave a Comment<span class="screen-reader-text"> on %s</span>', 'bigseotheme' ), array( 'span' => array( 'class' => array() ) ) ), get_the_title() ) );
			echo '</span>';
		}

		edit_post_link(
			sprintf(
				esc_html__( 'Edit %s', 'bigseotheme' ),
				the_title( '<span class="screen-reader-text">"', '"</span>', false )
				),
			'<span class="edit-link">',
			'</span>'
			);
	}
}


function bigseotheme_pagination() {
	echo '<div class="pagination">'. paginate_links() .'</div>';
}

function bigseotheme_posts_related(){

	$categories = get_the_category();
	$category_name = $categories[0]->term_id;


	if ( class_exists('WPSEO_Primary_Term') ) {
		$wpseo_primary_term = new WPSEO_Primary_Term( 'category', get_the_id() );
		$category_name = $wpseo_primary_term->get_primary_term();
	}

	// WP_Query arguments
	$args = array (
		'cat'                    => $category_name,
		'post__not_in' => array(get_the_ID()),
		'posts_per_page'         => '9',
		//'orderby'				=> 'rand',
		//'category_name'			=> $category_name,

		);

	// The Query
	$query = new WP_Query( $args );

	// The Loop
	if ( $query->have_posts() ) {
		echo '<section class="entry-related">';
		echo '<h4>Quiza tambien te interese :</h4>';
		echo '<div class="grid">';
		while ( $query->have_posts() ) {
			$query->the_post();
			get_template_part( 'template-parts/loops/loop', 'grid' );
		}
		echo '</div>';
		echo '</section>';

	}
	// Restore original Post Data
	wp_reset_postdata();

}

function bigseotheme_subtitle() {
	if(!bigseotheme_get_option_page('subtitle'))
		return;

	return '<p>'. bigseotheme_get_option_page('subtitle') . '</p>';
	
}


function bigseotheme_social_sharing_buttons() {

	// Get current page URL 
	$socialURL = get_permalink();

	// Get current page title
	$socialTitle = str_replace( ' ', '%20', get_the_title());

	// Get Post Thumbnail for pinterest
	$socialThumbnail = wp_get_attachment_image_src( get_post_thumbnail_id( get_the_ID() ), 'full' );

	// Construct sharing URL without using any script
	$twitterURL = 'https://twitter.com/intent/tweet?text='.$socialTitle.'&amp;url='.$socialURL;
	$facebookURL = 'https://www.facebook.com/sharer/sharer.php?u='.$socialURL;
	$googleURL = 'https://plus.google.com/share?url='.$socialURL;
	$bufferURL = 'https://www.linkedin.com/shareArticle?mini=true&url='.$socialURL.'&title='.$socialTitle;
	$pinterestURL = 'https://pinterest.com/pin/create/button/?url='.$socialURL.'&amp;media='.$socialThumbnail[0].'&amp;description='.$socialTitle;

	// Add sharing button at the end of page/page content
	$social = '<div class="entry-social">';
	$social .= '<h4 class="entry-social-title">Compartir</h4>';
	$social .= '<a class="social-link social-twitter" href="'. $twitterURL .'" target="_blank"><i class="fa fa-twitter"></i></a>';
	$social .= '<a class="social-link social-facebook" href="'.$facebookURL.'" target="_blank"><i class="fa fa-facebook"></i></a>';
	$social .= '<a class="social-link social-googleplus" href="'.$googleURL.'" target="_blank"><i class="fa fa-google-plus"></i></a>';
	$social .= '<a class="social-link social-linkedin" href="'.$bufferURL.'" target="_blank"><i class="fa fa-linkedin"></i></a>';
	$social .= '</div>';

	echo $social;
};


function bigseotheme_the_category() {
	$category = get_the_category();
	return $category[0]->cat_name;
}
add_filter( 'woocommerce_enqueue_styles', '__return_false' );


/*---------------------------


add_action('category_add_form_fields','add_extra_fields_to_category');
function add_extra_fields_to_category($taxonomy_name){
	?>
	<div class="form-field">
		<input type="file" name="my_image_upload" id="my_image_upload"  multiple="false" />
		<?php wp_nonce_field( 'my_image_upload', 'my_image_upload_nonce' ); ?>
		<input id="submit_my_image_upload" name="submit_my_image_upload" type="submit" value="Upload" />
	</div>
	<?php
}

add_action('create_category','save_extra_taxonomy_fields');

function save_extra_taxonomy_fields($term_id){

//collect all term related data for this new taxonomy
	$term_item = get_term($term_id,'category');
	$term_slug = $term_item->slug;

//collect our custom fields
	$term_category_text = sanitize_text_field($_POST['category-text']); 

//save our custom fields as wp-options
	update_option('term_category_text_' . $term_slug, $term_category_text); 

}
add_action('category_edit_form_fields','edit_extra_fields_for_category');

function edit_extra_fields_for_category($term){

//collect the term slug
	$term_slug = $term->slug;

//collect our saved term field information
	$term_category_text = get_option('term_category_text_' . $term_slug);

//output our additional fields
	?>
	<tr class="form-field">
		<th valign="top" scope="row">
			<label for="category-text"> Category Text Field </label>
		</th>
		<td>
			<input type="file" name="my_image_upload" id="my_image_upload"  multiple="false" />
			<?php wp_nonce_field( 'my_image_upload', 'my_image_upload_nonce' ); ?>
			<input id="submit_my_image_upload" name="submit_my_image_upload" type="submit" value="Upload" />

		</td>
	</tr>

	<?php
}

add_action('edit_category','save_extra_taxonomy_fields');

*/


function bigseotheme_lasts_posts() {

	// WP_Query arguments
	$args = array(
		'posts_per_page'         => '6',
		);

	// The Query
	$query = new WP_Query( $args );

	// The Loop
	if ( $query->have_posts() ) {
		
		echo '<div class="grid">';
		while ( $query->have_posts() ) {
			$query->the_post();
			get_template_part( 'template-parts/loops/loop', 'grid-standard' );
		}
		echo '</div>';

	}
	// Restore original Post Data
	wp_reset_postdata();
}